function [EST,TAB] = c2BayesImage(im,j1,j2,Nwt,eta,dra,gamint)
%% function [EST,TAB] = c2BayesImage(im,j1,j2,Nwt,eta,dra,gamint)
%
% Bayesian estimation of the multifractality parameter c2 for images
%
% INPUT:
%   im      image to be analyzed
%   j1      finest scale to use in estimation [default: 1]
%   j2      coarsest scale to use in estimation [default: log2(min(size(im)))-4]
%   Nwt     number of vanishing moments of wavelet 
%   eta     bandwidth parameter for Whittle approximation [default and recommended: 0.25]
%   dra     radial / angular sampling in 1D Hankel computation  [default and recommended: [1/2 1]]
%   gamint  fractional integration by order gamint to ensure minimum
%           regularity of image [default: 0]
%
% OUTPUT:
%   EST.c2 and EST.c20
%       structure with estimates of c2 (and intersept c20) obtained with
%       .MMSE   Bayesian MMSE estimator 
%       .MAP    Bayesian MAP estimator 
%       .LS     least-squares estimator
%       .wLS    weighted least-squares estimator
%   TAB
%       structure with samples generated by MCMC (.c2 and .c20)
%       and corresponding log-posterior values (.crit)
%       can be used to monitor convergence: 
%           iteration number is hard-wired in "SampleHMC_Langevin.m", line 5
%
%--- Sebastien Combrexelle, Toulouse, 2014-2015
%
% NOTE: This function requires the compilation of the MEX file "Vop.c"
%       (in subfolder "core")
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If you use this code, please quote:
%
%
% @ARTICLE{CombrexelleTIP2015,
%   author = {Sebastien Combrexelle and Herwig Wendt and Nicolas Dobigeon and Jean-Yves Tourneret and Stephen McLaughlin and Patrice Abry},
%   title = {Bayesian Estimation of the Multifractality Parameter for Image Texture Using a Whittle Approximation},
%   journal = {IEEE Trans. Image Process},
%   volume = {},
%   number = {},
%   pages = {},
%   year = {2015},
%   note = {to appear}
% }
% 
% and
%
% @INPROCEEDINGS{CombrexelleEUSIPCO2015,
%   author = {Sebastien Combrexelle and Herwig Wendt and Jean-Yves Tourneret and Patrice Abry and Stephen McLaughlin},
%   title = {Bayesian estimation of the multifractality parameter for images via a closed-form Whittle likelihood},
%   booktitle = {European Signal Processing Conference (EUSIPCO)},
%   address = {Nice, France},
%   month = {September},
%   year = {2015}
% }
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 7; gamint = 0;end
if nargin < 6; dra = [1/2 1];end
if nargin < 5; eta = 0.25;end
if nargin < 4; Nwt = 2;end
if nargin < 3; j2 = max(2,log2(min(size(im)))-4);end
if nargin < 2; j1 = 1; end

gamint=2;
% Periodogram storage
[IYm,Ni,Nj,wr,ind,VV] = PrepPerioImage(im,Nwt,j1,j2,eta,dra,gamint);
% PSD function storage
K = 3; INF.K = K;INF.wr = wr; INF.ind = ind; [psd,LLc]=psd_bayes(-0.08,0.4,j1,j2,Nj,INF);
% Sampling
[EST,TAB] = SampleHMC_Langevin(IYm,LLc,j1,j2,Ni,Nj);
% least squares estimates
[EST.c2.LS,EST.c20.LS] = regr_cp(VV,j1,j2,Nj(:,2)',0);
[EST.c2.wLS,EST.c20.wLS] = regr_cp(VV,j1,j2,Nj(:,2)',1);
end
