function [EST,TAB] = c2BayesSeries(X,j1,j2,Nwt,eta,gamint)
%% function [EST,TAB] = c2BayesSeries(X,j1,j2,Nwt,eta,gamint)
%
% Bayesian estimation of the multifractality parameter c2 for time series
%
% INPUT:
%   X       time series to be analyzed
%   j1      finest scale to use in estimation [default: 1]
%   j2      coarsest scale to use in estimation [default: log2(length(im))-4]
%   Nwt     number of vanishing moments of wavelet 
%   eta     bandwidth parameter for Whittle approximation [default and recommended: 1]
%   gamint  fractional integration by order gamint to ensure minimum
%           regularity of image [default: 0]
%
% OUTPUT:
%   EST.c2 and EST.c20
%       structure with estimates of c2 (and intersept c20) obtained with
%       .MMSE   Bayesian MMSE estimator 
%       .MAP    Bayesian MAP estimator 
%       .LS     least-squares estimator
%       .wLS    weighted least-squares estimator
%   TAB
%       structure with samples generated by MCMC (.c2 and .c20)
%       and corresponding log-posterior values (.critc2 and .critc20)
%       can be used to monitor convergence: 
%           iteration number is hard-wired on line 62 below
%
%--- S?bastien Combrexelle, Toulouse, 2013-2015
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If you use this code, please quote:
%
% @ARTICLE{CombrexelleTIP2015,
%   author = {S?bastien Combrexelle and Herwig Wendt and Nicolas Dobigeon and Jean-Yves Tourneret and Stephen McLaughlin and Patrice Abry},
%   title = {Bayesian Estimation of the Multifractality Parameter for Image Texture Using a Whittle Approximation},
%   journal = {IEEE Trans. Image Process},
%   volume = {},
%   number = {},
%   pages = {},
%   year = {2015},
%   note = {to appear}
% }
% 
% and
%
% @INPROCEEDINGS{WendtICASSP2013,
%   author = {Herwig Wendt and Nicolas Dobigeon and Jean-Yves Tourneret and Patrice Abry},
%   title = {Bayesian estimation for the multifractality parameter},
%   booktitle = {IEEE Int. Conf. Acoust., Speech, and Signal Proc. (ICASSP)},
%   address = {Vancouver, Canada},
%   month = {September},
%   year = {2013}
% }
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 6; gamint = 0;end;
if nargin < 5; eta = 1;end;
if nargin < 4; Nwt = 2;end
if nargin < 3; j2 = max(2,log2(length(X))-4);end
if nargin < 2; j1 = 1; end

% Periodogram
[IYm,Ni,Nj,ind,VV] = PrepPerioSerie(X,Nwt,j1,j2,eta,gamint);
% PSD function storage
[psd,LLc] = psd_bayes_serie(-0.08,0.55,j1,j2,Nj,ind);
% Sampling
N=length(X); Nmc=min(8000,max(2000,1/2*(log2(N)-8)*1000)); Nbi=round(Nmc/2);
[EST,TAB] = SampleGibbsRW(IYm,LLc,j1,j2,Ni,Nj, Nmc, Nbi);
% least squares estimates
[EST.c2.LS,EST.c20.LS] = regr_cp(VV,j1,j2,Nj(:,2)',0);
[EST.c2.wLS,EST.c20.wLS] = regr_cp(VV,j1,j2,Nj(:,2)',1);

end


